@@ -8,7 +8,7 @@
 	*  Free Software Foundation; either version 2 of the License, or (at your  *
 	*  option) any later version.                                              *
 	\**************************************************************************/
-	/* $Id: class.uiaccounts.inc.php,v 1.58.2.1 2004/08/28 13:44:27 ralfbecker Exp $ */
+	/* $Id: class.uiaccounts.inc.php,v 1.58.2.3 2005/02/15 08:29:29 ralfbecker Exp $ */
 
 	class uiaccounts
 	{
@@ -901,7 +901,7 @@
 			$p->set_block('edit','select');
 			$p->set_block('edit','popwin');
 
-			$accounts = CreateObject('phpgwapi.accounts',$group_info['account_id'],'u');
+			$accounts = CreateObject('phpgwapi.accounts',$group_info['account_id'],'g');
 
 			if (!is_object($GLOBALS['phpgw']->uiaccountsel))
 			{
@@ -1230,7 +1230,7 @@
 				$checked = (@$userData['account_permissions'][$app] || @$db_perms[$app]) && $_account_id ? ' checked="1"' : '';
 				$part[$i&1] = sprintf('<td>%s</td><td><input type="checkbox" name="account_permissions[%s]" value="True"%s>',
 					$data['title'],$app,$checked).	
-					($this->apps_with_acl[$app]?'<a href="'.$GLOBALS['phpgw']->link('/index.php','menuaction=preferences.uiaclprefs.index&acl_app='.$app.'&owner='.$_account_id)
+					($this->apps_with_acl[$app] && $_account_id?'<a href="'.$GLOBALS['phpgw']->link('/index.php','menuaction=preferences.uiaclprefs.index&acl_app='.$app.'&owner='.$_account_id)
 					. '"><img src="'.$GLOBALS['phpgw']->common->image('phpgwapi','edit').'" border="0" hspace="3" align="absmiddle" title="'
 					. lang('Grant Access').'"></a>':'&nbsp;').'</td>';
 
