@@ -10,7 +10,7 @@
   *  option) any later version.                                              *
   \**************************************************************************/
 
-  /* $Id: functions.inc.php,v 1.25 2004/01/27 15:19:13 reinerj Exp $ */
+  /* $Id: functions.inc.php,v 1.25.2.1 2004/11/17 10:52:35 ralfbecker Exp $ */
 
 define("COMIC_STATIC",  0);
 define("COMIC_SNARFED", 1);
@@ -523,8 +523,7 @@ function comic_error($image_location, $status, &$comic_url)
      * compose the error comic url
      *************************************************************************/
     $comic_url = $GLOBALS['phpgw_info']["server"]["webserver_url"]
-        ."/".$GLOBALS['phpgw_info']["flags"]["currentapp"]
-        ."/images/template"
+        ."/comic/images/template"
         .$label
         .$image_size
         .".png";
