@@ -23,6 +23,9 @@
 # Document
 #
 # Script changed 2004 May 21 Reiner Jung
+# Script changed 2005 Apr 15 by Ralf Becker and Wim Bonis
+
+BRANCH=Version-1_0_0-branch
 
 SPECFILE=egroupware.spec
 SPECFILE2=egroupware-allapp.spec
@@ -42,10 +45,12 @@ PACKAGING=`grep "%define packaging" $SPECFILE | cut -f3 -d' '`
 PACKAGINGFEDORA=`grep "Release:" $SPECFILEFEDORA | cut -f2 -d' '`
                                                                                                                              
 HOMEBUILDDIR=`whoami`
-ANONCVSDIR=/build_root/egroupware
-ANONCVSDIRFEDORA=/build_root/fedora
-ANONCVSDIRFEDORABUILD=/build_root/fedora/egroupware
-RHBASE=/home/$HOMEBUILDDIR/redhat
+CVSACCOUNT=ext:ralfbecker
+#CVSACCOUNT=pserver:anonymous
+ANONCVSDIR=/tmp/build_root/egroupware
+ANONCVSDIRFEDORA=/tmp/build_root/fedora
+ANONCVSDIRFEDORABUILD=/tmp/build_root/fedora/egroupware
+RHBASE=$HOME/rpm
 SRCDIR=$RHBASE/SOURCES
 SPECDIR=$RHBASE/SPECS
 LOGFILE=$SPECDIR/build-$PACKAGENAME-$VERSION-$PACKAGING.log
@@ -57,13 +62,31 @@ MD5SUM=$SRCDIR/md5sum-$PACKAGENAME-$VERSION-$PACKAGING.txt
 MD5SUMFEDORA=$SRCDIR/md5sum-$PACKAGENAMEFEDORA-$VERSIONFEDORA.$PACKAGINGFEDORA.txt
 
 
+
+mkdir -p $RHBASE/SOURCES $RHBASE/SPECS $RHBASE/BUILD $RHBASE/SRPMS $RHBASE/RPMS $ANONCVSDIR $ANONCVSDIRFEDORA $ANONCVSDIRFEDORABUILD
+
+cp $SPECFILE $SPECFILE2 $SPECFILEFEDORA $RHBASE/SPECS/
+
 echo "Start Build Process of - $PACKAGENAME $VERSION"                           	 > $LOGFILE
 echo "---------------------------------------"              				>> $LOGFILE 2>&1
 date                                                        				>> $LOGFILE 2>&1
 cd $ANONCVSDIR
-cvs -z9 update -r Version-1_0_0-branch -dP                                     		>> $LOGFILE 2>&1
+
+if [ ! -d egroupware ] ; then
+
+	[ $CVSACCOUT = 'pserver:anonymous'] && cvs -d:$CVSACCOUNT@cvs.sourceforge.net:/cvsroot/egroupware login
+
+	cvs -d:$CVSACCOUNT@cvs.sourceforge.net:/cvsroot/egroupware co -r $BRANCH egroupware
+	cd egroupware
+	cvs -d:$CVSACCOUNT@cvs.sourceforge.net:/cvsroot/egroupware co -r $BRANCH all
+
+fi
+cd $ANONCVSDIR
+
+cvs -z9 update -r $BRANCH -dP                                     		>> $LOGFILE 2>&1
+
 echo ":pserver:anonymous@cvs.sourceforge.net:/cvsroot/egroupware" > Root.anonymous	
-find . -type d -name CVS -exec cp /build_root/egroupware/Root.anonymous {}/Root \;	>> $LOGFILE 2>&1
+find . -type d -name CVS -exec cp Root.anonymous {}/Root \;				>> $LOGFILE 2>&1
 rm Root.anonymous
 echo "End from CVS update"						     		>> $LOGFILE 2>&1
 echo "---------------------------------------"      				        >> $LOGFILE 2>&1
@@ -72,13 +95,13 @@ find . -type f -exec chmod 644 {} \;
 echo "Change the direcory rights back"					     		>> $LOGFILE 2>&1
 echo "---------------------------------------"      				        >> $LOGFILE 2>&1
 
-clamscan -r $ANONCVSDIR --log=$VIRUSSCAN
+# clamscan -r $ANONCVSDIR --log=$VIRUSSCAN
+# 
+# echo "End from Anti Virus Scan"						     		>> $LOGFILE 2>&1
+# echo "---------------------------------------"      				        >> $LOGFILE 2>&1
 
-echo "End from Anti Virus Scan"						     		>> $LOGFILE 2>&1
-echo "---------------------------------------"      				        >> $LOGFILE 2>&1
-
-cd $ANONCVSDIR/..
-tar czvf $SRCDIR/$PACKAGENAME-$VERSION-$PACKAGING.tar.gz egroupware  			>> $LOGFILE 2>&1
+cd $ANONCVSDIR
+tar czvf $SRCDIR/$PACKAGENAME-$VERSION-$PACKAGING.tar.gz egroupware  			2>&1 | tee -a $LOGFILE
 tar cjvf $SRCDIR/$PACKAGENAME-$VERSION-$PACKAGING.tar.bz2 egroupware 			>> $LOGFILE 2>&1
 zip -r -9 $SRCDIR/$PACKAGENAME-$VERSION-$PACKAGING.zip egroupware  	  		>> $LOGFILE 2>&1
 echo "End Build Process of tar.gz, tar.bz, zip"						>> $LOGFILE 2>&1	
@@ -99,7 +122,8 @@ md5sum $SRCDIR/$PACKAGENAME-$VERSION-$PACKAGING.zip | cut -f1 -d' '    			>> $MD
 echo "End Build md5sum of tar.gz, tar.bz, zip"              				>> $LOGFILE 2>&1
 echo "---------------------------------------"              				>> $LOGFILE 2>&1
 echo "sign the md5sum file"								>> $LOGFILE 2>&1
-gpg --clearsign $MD5SUM									>> $LOGFILE 2>&1
+rm -f $MD5SUM.asc									>> $LOGFILE 2>&1
+gpg --local-user packager@egroupware.org --clearsign $MD5SUM				>> $LOGFILE 2>&1
 echo "---------------------------------------"              				>> $LOGFILE 2>&1
 
 echo "delete the original md5sum file"							>> $LOGFILE 2>&1
@@ -108,33 +132,36 @@ echo "---------------------------------------"              				>> $LOGFILE 2>&1
 
 
 echo "Build signed source files"			    				>> $LOGFILE 2>&1
-gpg -s $SRCDIR/$PACKAGENAME-$VERSION-$PACKAGING.tar.gz		    			>> $LOGFILE 2>&1
-gpg -s $SRCDIR/$PACKAGENAME-$VERSION-$PACKAGING.tar.bz2		    			>> $LOGFILE 2>&1 
-gpg -s $SRCDIR/$PACKAGENAME-$VERSION-$PACKAGING.zip		    			>> $LOGFILE 2>&1
+rm -f $SRCDIR/$PACKAGENAME-$VERSION-$PACKAGING.tar.gz.gpg		 		>> $LOGFILE 2>&1
+gpg --local-user packager@egroupware.org -s $SRCDIR/$PACKAGENAME-$VERSION-$PACKAGING.tar.gz 		>> $LOGFILE 2>&1
+rm -f $SRCDIR/$PACKAGENAME-$VERSION-$PACKAGING.tar.bz2.gpg		    		>> $LOGFILE 2>&1
+gpg --local-user packager@egroupware.org -s $SRCDIR/$PACKAGENAME-$VERSION-$PACKAGING.tar.bz2		>> $LOGFILE 2>&1 
+rm -f $SRCDIR/$PACKAGENAME-$VERSION-$PACKAGING.zip.gpg		    			>> $LOGFILE 2>&1
+gpg --local-user packager@egroupware.org -s $SRCDIR/$PACKAGENAME-$VERSION-$PACKAGING.zip		>> $LOGFILE 2>&1
 echo "End build of signed of tar.gz, tar.bz, zip"           				>> $LOGFILE 2>&1
-echo "---------------------------------------"              				>> $LOGFILE 2>&1
+echo "------------------------------------------"              				>> $LOGFILE 2>&1
 
 
 
 cd $SPECDIR
-rpmbuild -ba --sign $SPECFILE			                    			>> $LOGFILE 2>&1
+rpmbuild -ba --sign $SPECFILE                 			2>&1 | tee -a $LOGFILE
 echo "End Build Process of - $PACKAGENAME $VERSION single packages"      		>> $LOGFILE 2>&1
 echo "---------------------------------------"              				>> $LOGFILE 2>&1
-rpmbuild -ba --sign $SPECFILE2			             				>> $LOGFILE 2>&1
+rpmbuild -ba --sign $SPECFILE2        				2>&1 | tee -a $LOGFILE
 echo "End Build Process of - $PACKAGENAME $VERSION all applications"     		>> $LOGFILE 2>&1
 echo "---------------------------------------"      				        >> $LOGFILE 2>&1
 
 
-echo "Change the CVS dir back from anonymous to CVS user"		     		>> $LOGFILE 2>&1
-echo "---------------------------------------"      				        >> $LOGFILE 2>&1
-cd $ANONCVSDIR
-echo ":ext:reinerj@cvs.sourceforge.net:/cvsroot/egroupware" > Root.reinerj		
-find . -type d -name CVS -exec cp /build_root/egroupware/Root.reinerj {}/Root \;	>> $LOGFILE 2>&1
-rm Root.reinerj
-echo "Change the direcory rights back"					     		>> $LOGFILE 2>&1
-echo "---------------------------------------"      				        >> $LOGFILE 2>&1
-find . -type d -exec chmod 775 {} \;
-find . -type f -exec chmod 644 {} \;
+#echo "Change the CVS dir back from anonymous to CVS user"		     		>> $LOGFILE 2>&1
+#echo "---------------------------------------"      				        >> $LOGFILE 2>&1
+#cd $ANONCVSDIR
+#echo ":ext:ralfbecker@cvs.sourceforge.net:/cvsroot/egroupware" > Root.reinerj		
+#find . -type d -name CVS -exec cp /build_root/egroupware/Root.reinerj {}/Root \;	>> $LOGFILE 2>&1
+#rm Root.reinerj
+#echo "Change the direcory rights back"					     		>> $LOGFILE 2>&1
+#echo "---------------------------------------"      				        >> $LOGFILE 2>&1
+#find . -type d -exec chmod 775 {} \;
+#find . -type f -exec chmod 644 {} \;
 
 
 ##############################################################################################################
@@ -144,28 +171,6 @@ find . -type f -exec chmod 644 {} \;
 ############################################################################################################## 
 
 
-echo "Start Build Process of - $PACKAGENAMEFEDORA $VERSIONFEDORA $PACKAGINGFEDORA"       > $LOGFILEFEDORA
-echo "---------------------------------------"                                          >> $LOGFILEFEDORA 2>&1
-date                                                                                    >> $LOGFILEFEDORA 2>&1
-cd $ANONCVSDIRFEDORA
-cvs -z9 -d:ext:reinerj@cvs.sourceforge.net:/cvsroot/egroupware co -r Version-1_0_0-branch egroupware		>> $LOGFILEFEDORA 2>&1
-echo "must wait to finish this job"                                                     >> $LOGFILEFEDORA 2>&1
-cd $ANONCVSDIRFEDORABUILD	                                                        >> $LOGFILEFEDORA 2>&1
-cvs co -r Version-1_0_0-branch all                                                      >> $LOGFILEFEDORA 2>&1
-echo "first files are updated and now we must delete the old ones"  			>> $LOGFILEFEDORA 2>&1
-cvs -z9 update -dP 									>> $LOGFILEFEDORA 2>&1
-find . -type d -name CVS | xargs rm -rf
-find . -type d -exec chmod 775 {} \;
-find . -type f -exec chmod 644 {} \;
-
-echo "End from Fedora CVS update"                                                       >> $LOGFILEFEDORA 2>&1
-echo "---------------------------------------"                                          >> $LOGFILEFEDORA 2>&1
-                                                                                                                             
-clamscan -r $ANONCVSDIRFEDORABUILD --log=$VIRUSSCANDEFORA
-                                                                                                                             
-echo "End from Fedora Anti Virus Scan"                                                  >> $LOGFILEFEDORA 2>&1
-echo "---------------------------------------"                                          >> $LOGFILEFEDORA 2>&1
-                                                                                                                             
 cd $ANONCVSDIRFEDORA
 tar czvf $SRCDIR/$PACKAGENAMEFEDORA-$VERSIONFEDORA.$PACKAGINGFEDORA.tar.gz egroupware   >> $LOGFILEFEDORA 2>&1
                                                                                                                              
@@ -186,15 +191,18 @@ echo "---------------------------------------"
 ##############################################################################################################
 
 
-echo "Start build Bitrock packages"	                                                 > $LOGFILEFEBIT
-echo "---------------------------------------"                                          >> $LOGFILEFEBIT 2>&1
-date                                                                                    >> $LOGFILEFEBIT 2>&1
+#echo "Start build Bitrock packages"	                                                 > $LOGFILEFEBIT
+#echo "---------------------------------------"                                          >> $LOGFILEFEBIT 2>&1
+#date                                                                                    >> $LOGFILEFEBIT 2>&1
+#
+#cd $ANONCVSDIRFEDORA
+#                                                                                                                            
+#echo "build bitrock Linux package" 							>> $LOGFILEFEBIT 2>&1
+#/opt/installbuilder-2.0/bin/builder build /opt/installbuilder-2.0/projects/egroupware.xml linux
+#echo "build bitrock Windows package" 							>> $LOGFILEFEBIT 2>&1
+#/opt/installbuilder-2.0/bin/builder build /opt/installbuilder-2.0/projects/egroupware.xml windows
 
-cd $ANONCVSDIRFEDORA
-                                                                                                                            
-/opt/installbuilder-1.2.1/bin/builder build /opt/installbuilder-1.2.1/projects/egroupware.xml
-
-rm -rf egroupware
+#rm -rf egroupware
 echo "Fedora Build Root deleted $PACKAGENAMEFEDORA $VERSIONFEDORA $PACKAGINGFEDORA"     >> $LOGFILEFEBIT 2>&1
 echo "---------------------------------------"                                          >> $LOGFILEFEBIT 2>&1
 
