@@ -10,7 +10,7 @@
 	*  option) any later version.                                              *
 	\**************************************************************************/
 
-	/* $Id: class.uietemplate.inc.php,v 1.80.2.5 2004/09/20 18:50:36 ralfbecker Exp $ */
+	/* $Id: class.uietemplate.inc.php,v 1.80.2.7 2005/02/12 14:02:39 ralfbecker Exp $ */
 
 	include_once(PHPGW_INCLUDE_ROOT . '/etemplate/inc/class.boetemplate.inc.php');
 
@@ -1013,6 +1013,24 @@
 			return $html;
 		}
 
+		/**
+		 * applies stripslashes recursivly on each element of an array
+		 * 
+		 * @param array &$var 
+		 * @return array
+		 */
+		function array_stripslashes($var)
+		{
+			if (!is_array($var))
+			{
+				return stripslashes($var);
+			}
+			foreach($var as $key => $val)
+			{
+				$var[$key] = is_array($val) ? $this->array_stripslashes($val) : stripslashes($val);
+			}
+			return $var;
+		}
 
 		/*!
 		@function process_show
@@ -1037,6 +1055,10 @@
 			}
 			$content_in = $cname ? array($cname => $content) : $content;
 			$content = array();
+			if (get_magic_quotes_gpc())
+			{
+				$content_in = $this->array_stripslashes($content_in);
+			}
 			$GLOBALS['phpgw_info']['etemplate']['validation_errors'] = array();
 			$this->canceled = $this->button_pressed = False;
 
@@ -1053,7 +1075,7 @@
 				}
 				$value = $this->get_array($content_in,$form_name,True);
 
-				if (isset($attr['blur']) && $attr['blur'] == stripslashes($value))
+				if (isset($attr['blur']) && $attr['blur'] == $value)
 				{
 					$value = '';	// blur-values is equal to emtpy
 				}
@@ -1076,20 +1098,12 @@
 						}
 						break;
 					case 'htmlarea':
-						if (isset($value))
-						{
-							$value = stripslashes($value);
-						}
 						$this->set_array($content,$form_name,$value);
 						break;
 					case 'int':
 					case 'float':
 					case 'text':
 					case 'textarea':
-						if (isset($value))
-						{
-							$value = stripslashes($value);
-						}
 						if ($value === '' && $attr['needed'])
 						{
 							$GLOBALS['phpgw_info']['etemplate']['validation_errors'][$form_name] = lang('Field must not be empty !!!',$value);
