@@ -14,7 +14,7 @@
 	* Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA            *
 	\**************************************************************************/
 
-	/* $Id: class.uifilemanager.inc.php,v 1.17.2.2 2004/08/18 08:57:31 ralfbecker Exp $ */
+	/* $Id: class.uifilemanager.inc.php,v 1.17.2.3 2004/12/12 06:35:24 dawnlinux Exp $ */
 
 	class uifilemanager
 	{
@@ -209,7 +209,7 @@
 
 				if($test[mime_type]!='Directory')
 				{
-					die('Fake Base directory does not exist and could not be created, please ask the adminstrator to check the global configuration.');
+					die('Fake Base directory does not exist and could not be created, please ask the administrator to check the global configuration.');
 				}
 				else
 				{
