@@ -11,7 +11,7 @@
 	*  option) any later version.                                                 *
 	\*****************************************************************************/
 
-	/* $Id: class.uiforum.inc.php,v 1.11.2.1 2004/09/11 16:19:16 alpeb Exp $ */
+	/* $Id: class.uiforum.inc.php,v 1.11.2.2 2005/03/15 15:29:53 ralfbecker Exp $ */
 
 	class uiforum
 	{
@@ -495,7 +495,7 @@
 				'POST_ACTION'   => $GLOBALS['phpgw']->link('/index.php','menuaction=forum.boforum.post'),
 				'CAT_ID'        => $this->bo->cat_id,
 				'FORUM_ID'      => $this->bo->forum_id,
-				'TYPE'          => $GLOBALS['HTTP_GET_VARS']['type'],
+				'TYPE'          => htmlspecialchars($GLOBALS['HTTP_GET_VARS']['type']),
 				'ACTION'        => 'post',
 				'LANG_DATE'     => lang('Date'),
 				'LANG_SUBJECT'  => lang('Subject'),
