@@ -12,7 +12,7 @@
 	* http://www.goldenglair.com                                               *
 	\**************************************************************************/
 
-	/* $Id: class.uinews.inc.php,v 1.33.2.1 2004/08/21 03:57:02 dawnlinux Exp $ */
+	/* $Id: class.uinews.inc.php,v 1.33.2.2 2005/01/12 10:28:20 dawnlinux Exp $ */
 
 	class uinews
 	{
@@ -357,9 +357,18 @@
 
 			if($_POST['cancel'])
 			{
-				Header('Location: ' . $GLOBALS['phpgw']->link('/index.php','menuaction=news_admin.uinews.write_news'));
-				return;
+			  if(isset($this->news_data['category']))
+			  {
+			      Header('Location: ' . $GLOBALS['phpgw']->link('/index.php','menuaction=news_admin.uinews.write_news&cat_id='.$this->news_data['category']));
+			      return;
+			  }
+			  else
+			  {
+			      Header('Location: ' . $GLOBALS['phpgw']->link('/index.php','menuaction=news_admin.uinews.write_news'));
+		    	      return;
+                          }
 			}
+
 			if(is_array($this->news_data))
 			{
 				if(!$this->news_data['subject'])
