@@ -13,7 +13,7 @@
 *  option) any later version.                                              *
 \**************************************************************************/
 
-	/* $Id: class.sokb.inc.php,v 1.27.2.11 2004/10/29 16:31:19 alpeb Exp $ */
+	/* $Id: class.sokb.inc.php,v 1.27.2.12 2004/12/31 13:45:08 alpeb Exp $ */
 
 	/**
 	* Data manipulation layer of the Knowledge Base. Methods to be used only  by methods in the bo class.
@@ -21,7 +21,7 @@
 	* Last Editor:	$Author: alpeb $
 	* @author		Alejandro Pedraza
 	* @package		phpbrain
-	* @version		$Revision: 1.27.2.11 $
+	* @version		$Revision: 1.27.2.12 $
 	* @license		GPL
 	**/
 	class sokb
@@ -247,13 +247,16 @@
 			$all_words = $this->db->db_addslashes($all_words);
 			$all_words = strlen($all_words)? explode(' ', $all_words) : False;
 			$each_field = array();
-			foreach ($all_words as $word)
+			if ($all_words)
 			{
-				$each_field[] = "(" . implode(" LIKE '%$word%' OR ", $target_fields) . " LIKE '%$word%')";
-			}
-			if ($each_field)
-			{
-				$sql .= " AND " . implode(" AND ", $each_field);
+				foreach ($all_words as $word)
+				{
+					$each_field[] = "(" . implode(" LIKE '%$word%' OR ", $target_fields) . " LIKE '%$word%')";
+				}
+				if ($each_field)
+				{
+					$sql .= " AND " . implode(" AND ", $each_field);
+				}
 			}
 
 			// "with the exact phrase" filtering
