@@ -12,7 +12,7 @@
 	*  Free Software Foundation; either version 2 of the License, or (at your  *
 	*  option) any later version.                                              *
 	\**************************************************************************/
-	/* $Id: index.php,v 1.4 2004/01/26 05:47:29 milosch Exp $ */
+	/* $Id: index.php,v 1.4.2.1 2005/02/14 16:57:10 alpeb Exp $ */
 
 	$phpgw_info = array();
 	$GLOBALS['phpgw_info']['flags'] = array(
@@ -25,5 +25,5 @@
 	$obj = CreateObject('phpbrain.uikb');
 	$obj->index();
 
-	$GLOBALS['phpgw']->common->phpgw_exit();
+	$GLOBALS['phpgw']->common->phpgw_exit(true);
 ?>
