@@ -24,7 +24,7 @@
 	* along with this library; if not, write to the Free Software Foundation,  *
 	* Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA            *
 	\**************************************************************************/
-	/* $Id: class.accounts_ldap.inc.php,v 1.146.2.4 2004/08/31 15:16:56 mgalgoci Exp $ */
+	/* $Id: class.accounts_ldap.inc.php,v 1.146.2.5 2005/04/12 09:54:46 ralfbecker Exp $ */
 
 	class accounts_
 	{
@@ -83,7 +83,7 @@
 				}
 			}
 			$this->data['account_dn']  = $allValues[0]['dn'];
-			$this->data['fullname']    = $allValues[0]['cn'][0];
+			$this->data['fullname']    = $GLOBALS['phpgw']->translation->convert($allValues[0]['cn'][0],'utf-8');
 
 			if ($GLOBALS['phpgw_info']['server']['ldap_extra_attributes'])
 			{
