@@ -16,7 +16,7 @@
   *  option) any later version.                                              *
   \**************************************************************************/
 
-  /* $Id: class.schema_proc_pgsql.inc.php,v 1.27.2.1 2004/07/25 01:34:57 ralfbecker Exp $ */
+  /* $Id: class.schema_proc_pgsql.inc.php,v 1.27.2.2 2004/11/08 16:14:48 ralfbecker Exp $ */
 
 	class schema_proc_pgsql
 	{
@@ -156,7 +156,7 @@
 				case 'text':
 				case 'blob':
 				case 'date':
-				case 'bool';
+				case 'bool':
 					$sTranslated = "'type' => '$sType'";
 					break;
 			}
