@@ -23,7 +23,7 @@
   * Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA            *
   \**************************************************************************/
 
-  /* $Id: class.sessions.inc.php,v 1.129.4.5 2004/09/08 13:16:01 ralfbecker Exp $ */
+  /* $Id: class.sessions.inc.php,v 1.129.4.7 2005/03/07 06:42:17 ralfbecker Exp $ */
 
 	/* sessions_type setup moved after the class below - milosch */
 
@@ -1302,6 +1302,23 @@
 
 	if(empty($GLOBALS['phpgw_info']['server']['sessions_type']))
 	{
-		$GLOBALS['phpgw_info']['server']['sessions_type'] = 'db';
+		$GLOBALS['phpgw_info']['server']['sessions_type'] = 'php4';	// the more performant default
+	}
+	// for php4 sessions, check if the extension is loaded, try loading it and fallback to db sessions if not
+	if ($GLOBALS['phpgw_info']['server']['sessions_type'] == 'php4' && !extension_loaded('session'))
+	{
+		// some constanst for pre php4.3
+		if (!defined('PHP_SHLIB_SUFFIX'))
+		{
+			define('PHP_SHLIB_SUFFIX',strtoupper(substr(PHP_OS, 0,3)) == 'WIN' ? 'dll' : 'so');
+		}
+		if (!defined('PHP_SHLIB_PREFIX'))
+		{
+			define('PHP_SHLIB_PREFIX',PHP_SHLIB_SUFFIX == 'dll' ? 'php_' : '');
+		}
+		if (!function_exists('dl') || !@dl(PHP_SHLIB_PREFIX.'session'.'.'.PHP_SHLIB_SUFFIX))
+		{
+			$GLOBALS['phpgw_info']['server']['sessions_type'] = 'db';	// fallback if we have no php4 sessions support
+		}
 	}
 	include_once(PHPGW_API_INC.'/class.sessions_'.$GLOBALS['phpgw_info']['server']['sessions_type'].'.inc.php');
