@@ -22,7 +22,7 @@
 	 * Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA            *
 	 \**************************************************************************/
 
-	/* $Id: common_functions.inc.php,v 1.41.4.7 2004/10/21 18:13:46 lkneschke Exp $ */
+	/* $Id: common_functions.inc.php,v 1.41.4.8 2005/03/15 15:41:31 ralfbecker Exp $ */
 
 	/****************************************************************************\
 	 * Direct functions which are not part of the API classes                    *
@@ -1207,7 +1207,7 @@
 				}
 				else
 				{
-					if (preg_match('/<\/?[^>]*(script|onabort|onblur|onchange|onclick|ondblclick|onerror|onfocus|onkeydown|onkeypress|onkeyup|onload|onmousedown|onmousemove|onmouseout|onmouseover|onmouseup|onreset|onselect|onsubmit|onunload|javascript)+[^>]*>/i',$val))
+					if (preg_match('/<\/?[^>]*(iframe|script|onabort|onblur|onchange|onclick|ondblclick|onerror|onfocus|onkeydown|onkeypress|onkeyup|onload|onmousedown|onmousemove|onmouseout|onmouseover|onmouseup|onreset|onselect|onsubmit|onunload|javascript)+[^>]*>/i',$val))
 					{
 						//echo "<p>*** _check_script_tag($name): unset($name [$key]) ***</p>\n";
 						unset($var[$key]);
