@@ -9,7 +9,7 @@
 	*  option) any later version.                                              *
 	\**************************************************************************/
 
-	// $Id: tables_update.inc.php,v 1.95.2.8 2004/11/06 12:20:09 ralfbecker Exp $
+	// $Id: tables_update.inc.php,v 1.95.2.9 2005/04/15 16:33:27 ralfbecker Exp $
 	// $Source: /cvsroot/egroupware/phpgwapi/setup/tables_update.inc.php,v $
 
 	/* Include older phpGroupWare update support */
@@ -1642,4 +1642,11 @@
 		$GLOBALS['setup_info']['phpgwapi']['currentver'] = '1.0.0.006';
 		return $GLOBALS['setup_info']['phpgwapi']['currentver'];
 	}
+
+	$test[] = '1.0.0.006';
+	function phpgwapi_upgrade1_0_0_006()
+	{
+		$GLOBALS['setup_info']['phpgwapi']['currentver'] = '1.0.0.007';
+		return $GLOBALS['setup_info']['phpgwapi']['currentver'];
+	}
 ?>
