@@ -24,7 +24,7 @@
 	* along with this program; if not, write to the Free Software       *
 	* Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.         *
 	\*******************************************************************/
-	/* $Id: class.uiprojects.inc.php,v 1.108.2.8 2004/11/06 12:15:55 ralfbecker Exp $ */
+	/* $Id: class.uiprojects.inc.php,v 1.108.2.9 2005/02/18 13:24:46 ralfbecker Exp $ */
 	// $Source: /cvsroot/egroupware/projects/inc/class.uiprojects.inc.php,v $
 
 	class uiprojects
@@ -1608,7 +1608,7 @@
 
 		function view_project()
 		{
-			$action		= $_GET['action'];
+			$action		= $_GET['action'] ? $_GET['action'] : 'mains';
 			$pro_main	= $_GET['pro_main'];
 			$project_id	= $_GET['project_id'];
 			$public_view	= $_GET['public_view'];
