@@ -9,7 +9,7 @@
   *  option) any later version.                                              *
   \**************************************************************************/
 
-  /* $Id: check_install.php,v 1.21.2.7 2004/08/17 16:55:41 ralfbecker Exp $ */
+  /* $Id: check_install.php,v 1.21.2.8 2005/02/21 08:04:51 ralfbecker Exp $ */
 
 	$run_by_webserver = !!$_SERVER['PHP_SELF'];
 	$is_windows = strtoupper(substr(PHP_OS,0,3)) == 'WIN';
@@ -132,6 +132,10 @@
 			'func' => 'extension_check',
 			'warning' => '<div id="setup_info">' . lang('The imap extension is needed by the two email apps (even if you use email with pop3 as protocoll).') . '</div>'
 		),
+		'session' => array(
+			'func' => 'extension_check',
+			'warning' => '<div id="setup_info">' . lang('The session extension is needed to use php4 session (db-sessions work without).') . "</div>"
+		),	
 		'.' => array(
 			'func' => 'permission_check',
 			'is_world_writable' => False,
