@@ -11,7 +11,7 @@
 	*  option) any later version.                                              *
 	\**************************************************************************/
 
-	/* $Id: class.Content_SO.inc.php,v 1.18.2.1 2004/08/06 18:31:04 ralfbecker Exp $ */
+	/* $Id: class.Content_SO.inc.php,v 1.18.2.2 2005/04/15 14:57:33 ralfbecker Exp $ */
 
 	class Content_SO
 	{
@@ -415,8 +415,8 @@
 			{
 				 return $lang ? 
 					array_merge(
-						unserialize($this->db->f('arguments')),
-						unserialize($this->db->f('arguments_lang')) 
+						(array) unserialize($this->db->f('arguments')),
+						(array) unserialize($this->db->f('arguments_lang')) 
 					) : 
 					unserialize($this->db->f('arguments'));
 			}
@@ -643,4 +643,4 @@
 					'block_id' => $block_id,
 				), __LINE__,__FILE__);
 		}
-	}
\ No newline at end of file
+	}
