@@ -9,7 +9,7 @@
   *  option) any later version.                                              *
   \**************************************************************************/
 
-  // $Id: viewticket_details.php,v 1.61.2.2 2004/08/21 19:26:12 dragob Exp $
+  // $Id: viewticket_details.php,v 1.61.2.3 2005/02/12 16:04:21 ralfbecker Exp $
   // $Source: /cvsroot/egroupware/tts/viewticket_details.php,v $
 
 
@@ -456,7 +456,7 @@
     $GLOBALS['phpgw']->template->set_var('lang_keep_present_state',
       lang('Keep the present state [%1].',id2field('phpgw_tts_states','state_name','state_id',$ticket['state'])));
 
-    $db = $GLOBALS['phpgw']->db;
+    $db = clone($GLOBALS['phpgw']->db);
     $db->query("select * from phpgw_tts_transitions where transition_source_state=".$ticket['state'],__LINE__,__FILE__);
 
     while($db->next_record())
