@@ -1,5 +1,5 @@
 <?php
-// $Id: transforms.php,v 1.7 2004/05/03 10:07:03 ralfbecker Exp $
+// $Id: transforms.php,v 1.7.2.1 2005/04/15 15:52:43 ralfbecker Exp $
 
 // The main parser components.  Each of these takes a line of text and scans it
 //   for particular wiki markup.  It converts markup elements to
@@ -308,7 +308,7 @@ function parse_code($text)
 
   if($in_code)
   {
-    if($text == "&lt;/code>\n")
+    if(preg_match("|^\s*&lt;/code>\s*|", $text))
     {
       $Entity[count($Entity)] = array('code', $buffer);
       $buffer  = '';
@@ -321,7 +321,7 @@ function parse_code($text)
   }
   else
   {
-    if($text == "&lt;code>\n")
+    if(preg_match("|^\s*&lt;code>\s*|", $text))
     {
       $in_code = 1;
       return '';
